Modules
- code
- diff
- review
- Git commit review: what a repository has pending (unstaged), staged, and recently committed,
and how to turn any one of those changes into the two files on disk the diff engine reads.
Shared by both front ends (
tui::components::review_dialog,web::session). - tui
Functions
- diff_
strings - Compute the difference between two programs, given as strings in a given language.